@@ -3,7 +3,7 @@ __author__ = 'Daniel Vaz Gaspar'
 __email__ = 'danielvazgaspar@gmail.com'
 
 
-from .models import Model, Base, SQLA
+from .models.sqla import Model, Base, SQLA
 from .base import AppBuilder
 from .baseviews import expose, BaseView
 from .views import GeneralView, ModelView, IndexView, FormWidget
