@@ -39,12 +39,13 @@ class FieldConverter(object):
     )
 
 
-    def __init__(self, datamodel, colname, label, description, validators):
+    def __init__(self, datamodel, colname, label, description, validators, default = None):
         self.datamodel = datamodel
         self.colname = colname
         self.label = label
         self.description = description
         self.validators = validators
+        self.default = default
 
     def convert(self):
         for conversion in self.conversion_table:
@@ -53,11 +54,13 @@ class FieldConverter(object):
                     return conversion[1](self.label,
                                          description=self.description,
                                          validators=self.validators,
-                                         widget=conversion[2]())
+                                         widget=conversion[2](),
+                                         default=self.default)
                 else:
                     return conversion[1](self.label,
                                          description=self.description,
-                                         validators=self.validators)
+                                         validators=self.validators,
+                                         default=self.default)
         log.error('Column %s Type not supported' % self.colname)
 
 
@@ -83,28 +86,28 @@ class GeneralModelConverter(object):
         else:
             return ""
 
-    def _get_func_related_query(self, prop, filter_rel_fields):
+    def _get_func_related_query(self, col_name, filter_rel_fields):
         if filter_rel_fields:
             for filter_rel_field in filter_rel_fields:
-                if filter_rel_field[0] == prop.key:
+                if filter_rel_field[0] == col_name:
                     sqla = filter_rel_field[1]
                     _filters = Filters().add_filter_list(sqla, filter_rel_field[2])
                     return lambda: sqla.query(_filters)[1]
-        rel_model = self.datamodel.get_model_relation(prop)
+        rel_model = self.datamodel.get_model_relation(col_name)
         return lambda: self.datamodel.session.query(rel_model)
 
 
-    def _convert_many_to_one(self, prop, label, description,
+    def _convert_many_to_one(self, col_name, label, description,
                              lst_validators, filter_rel_fields, form_props):
-        query_func = self._get_func_related_query(prop, filter_rel_fields)
+        query_func = self._get_func_related_query(col_name, filter_rel_fields)
         allow_blank = True
-        col = self.datamodel.get_relation_fk(prop)
+        col = self.datamodel.get_relation_fk(col_name)
         if not col.nullable:
             lst_validators.append(validators.Required())
             allow_blank = False
         else:
             lst_validators.append(validators.Optional())
-        form_props[self.datamodel.get_property_col(prop)] = \
+        form_props[col_name] = \
             QuerySelectField(label,
                              description=description,
                              query_factory=query_func,
@@ -113,11 +116,11 @@ class GeneralModelConverter(object):
                              widget=Select2Widget())
         return form_props
 
-    def _convert_many_to_many(self, prop, label, description,
+    def _convert_many_to_many(self, col_name, label, description,
                               lst_validators, filter_rel_fields, form_props):
-        query_func = self._get_func_related_query(prop, filter_rel_fields)
+        query_func = self._get_func_related_query(col_name, filter_rel_fields)
         allow_blank = True
-        form_props[self.datamodel.get_property_col(prop)] = \
+        form_props[col_name] = \
             QuerySelectMultipleField(label,
                                      description=description,
                                      query_factory=query_func,
@@ -126,53 +129,51 @@ class GeneralModelConverter(object):
                                      widget=Select2ManyWidget())
         return form_props
 
-    def _convert_field(self, col, label, description, lst_validators, form_props):
-        try:
-            if not col.nullable:
-                lst_validators.append(validators.Required())
-            else:
-                lst_validators.append(validators.Optional())
-            if col.unique:
-                lst_validators.append(Unique(self.datamodel, col))
+    def _convert_field(self, col_name, label, description, lst_validators, form_props):
+        if not self.datamodel.is_nullable(col_name):
+            lst_validators.append(validators.InputRequired())
+        else:
+            lst_validators.append(validators.Optional())
+        if self.datamodel.is_unique(col_name):
+            lst_validators.append(Unique(self.datamodel, col_name))
+        default_value = self.datamodel.get_col_default(col_name)
+        fc = FieldConverter(self.datamodel, col_name, label, description, lst_validators, default=default_value)
+        form_props[col_name] = fc.convert()
+        return form_props
 
-            fc = FieldConverter(self.datamodel, col.name, label, description, lst_validators)
-            form_props[col.name] = fc.convert()
-            return form_props
-        except Exception as e:
-            log.warning("Cannot convert field: {0} ({1})".format(col, label))
-
-    def _convert_prop(self, prop, label, description, lst_validators, filter_rel_fields, form_props):
-        if self.datamodel.is_relation(prop):
-            if self.datamodel.is_relation_many_to_one(prop) or self.datamodel.is_relation_one_to_one(prop):
-                return self._convert_many_to_one(prop, label,
+    def _convert_prop(self, col_name, label, description, lst_validators, filter_rel_fields, form_props):
+        if self.datamodel.is_relation(col_name):
+            if self.datamodel.is_relation_many_to_one(col_name) or \
+                    self.datamodel.is_relation_one_to_one(col_name):
+                return self._convert_many_to_one(col_name, label,
                                                  description,
                                                  lst_validators,
                                                  filter_rel_fields, form_props)
-            elif self.datamodel.is_relation_many_to_many(prop) or self.datamodel.is_relation_one_to_many(prop):
-                return self._convert_many_to_many(prop, label,
+            elif self.datamodel.is_relation_many_to_many(col_name) or \
+                    self.datamodel.is_relation_one_to_many(col_name):
+                return self._convert_many_to_many(col_name, label,
                                                   description,
                                                   lst_validators,
                                                   filter_rel_fields, form_props)
             else:
-                log.warning("Relation {0} not supported on {1}".format(prop.direction.name, prop))
+                log.warning("Relation {0} not supported".format(col_name))
         else:
-            col = self.datamodel.get_property_first_col(prop)
-            if not (self.datamodel.is_pk(col) or self.datamodel.is_fk(col)):
-                return self._convert_field(col, label, description, lst_validators, form_props)
+            if not (self.datamodel.is_pk(col_name) or self.datamodel.is_fk(col_name)):
+                return self._convert_field(col_name, label, description, lst_validators, form_props)
 
 
     def create_form(self, label_columns={}, inc_columns=[],
                     description_columns={}, validators_columns={},
                     extra_fields={}, filter_rel_fields=None):
         form_props = {}
-        for col in inc_columns:
-            if col in extra_fields:
-                form_props[col] = extra_fields.get(col)
+        for col_name in inc_columns:
+            if col_name in extra_fields:
+                form_props[col_name] = extra_fields.get(col_name)
             else:
-                prop = self.datamodel.get_col_property(col)
-                self._convert_prop(prop, self._get_label(col, label_columns),
-                                   self._get_description(col, description_columns),
-                                   self._get_validators(col, validators_columns),
+                #prop = self.datamodel.get_col_property(col)
+                self._convert_prop(col_name, self._get_label(col_name, label_columns),
+                                   self._get_description(col_name, description_columns),
+                                   self._get_validators(col_name, validators_columns),
                                    filter_rel_fields, form_props)
         return type('DynamicForm', (DynamicForm,), form_props)
 
